/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/

package org.fortiss.af3.rcp.application.advisors;

import static org.fortiss.af3.project.ui.perspective.ModelingPerspectiveFactory.MODELING_PERSPECTIVE_ID;

import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.ui.application.IWorkbenchConfigurer;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchAdvisor;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;
import org.eclipse.ui.ide.IDE;
import org.fortiss.af3.allocation.IAllocationService;
import org.fortiss.af3.exploration.service.IDSEBackendService;
import org.fortiss.af3.exploration.smt.backend.Z3Backend;
import org.fortiss.af3.exploration.ui.AF3ExplorationUIActivator;
import org.fortiss.af3.project.AF3Project;
import org.fortiss.af3.project.ui.AF3ProjectUI;
import org.fortiss.af3.timing.ITimingSpecificationService;
import org.fortiss.tooling.base.ToolingBase;
import org.fortiss.tooling.kernel.ToolingKernel;
import org.fortiss.tooling.kernel.ui.ToolingKernelUI;

/**
 * Workbench advisor for the AF3 RCP.
 * 
 * @author ratiu
 */
public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {

	/** {@inheritDoc} */
	@Override
	public WorkbenchWindowAdvisor
			createWorkbenchWindowAdvisor(IWorkbenchWindowConfigurer configurer) {
		return new ApplicationWorkbenchWindowAdvisor(configurer);
	}

	/** {@inheritDoc} */
	@Override
	public IAdaptable getDefaultPageInput() {
		return ResourcesPlugin.getWorkspace().getRoot();
	}

	/** {@inheritDoc} */
	@Override
	public void preStartup() {
		IDE.registerAdapters();
		AF3ExplorationUIActivator.registerWorkbenchListener();
	}

	/** {@inheritDoc} */
	@Override
	public void postStartup() {
		ToolingKernel.start();
		ToolingBase.start();
		ToolingKernelUI.start();
		AF3Project.start();
		AF3ProjectUI.start();
		IAllocationService.getInstance().startService();
		ITimingSpecificationService.getInstance().startService();
		IDSEBackendService.getInstance().startService();
	}

	/** {@inheritDoc} */
	@Override
	public void initialize(IWorkbenchConfigurer configurer) {
		configurer.setSaveAndRestore(true);
		ToolingKernel.initialize();
		ToolingBase.initialize();
		ToolingKernelUI.initialize();
		AF3Project.initialize();
		IAllocationService.getInstance().initializeService();
		IDSEBackendService dbs = IDSEBackendService.getInstance();
		dbs.initializeService();
		dbs.registerDSEBackend(new Z3Backend());
	}

	/** {@inheritDoc} */
	@Override
	public String getInitialWindowPerspectiveId() {
		return MODELING_PERSPECTIVE_ID;
	}
}
